pub enum DiffEntry {
Added {
path: String,
entry: ManifestEntry,
},
Removed {
path: String,
entry: ManifestEntry,
},
Modified {
path: String,
old: ManifestEntry,
new: ManifestEntry,
},
}Expand description
A single difference between two manifest versions.
Variants
Added
A path that exists in the new manifest but not the old.
Removed
A path that exists in the old manifest but not the new.
Modified
A path that exists in both manifests but with a different blob_hash.